.. :changelog:

History
-------

0.2.0 (2017-12-28)
++++++++++++++++++

* First release on PyPI.
* Initial models and REST API.

0.3.0 (2017-01-05)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-user-activities/compare/v0.2.0...v0.3.0>`_

* Improved REST API filters.

0.3.1 (2017-01-09)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-user-activities/compare/v0.3.0...v0.3.1>`_

* Fixed issues with migrations.

0.3.2 (2017-01-12)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-user-activities/compare/v0.3.1...v0.3.2>`_

* Fixed route names for SimpleRouter.

0.4.0 (2017-02-06)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-user-activities/compare/v0.3.2...v0.4.0>`_

* Optimized API
* Added additional filters to API
* Made updates to dependencies library

0.4.1 (2017-02-09)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-user-activities/compare/v0.4.0...v0.4.1>`_

* Fixed changelog
* Made updates to dependencies library

0.5.0 (2017-04-07)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-user-activities/compare/v0.4.0...v0.5.0>`_

* Fixed changelog
* Made updates to dependencies library

0.5.1 (2017-04-18)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-user-activities/compare/v0.5.0...v0.5.1>`_

* Made updates to dependencies library

0.5.2 (2017-05-16)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-user-activities/compare/v0.5.1...v0.5.2>`_

* Updated setup.py to read requirments.txt

0.5.3 (2018-08-13)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-user-activities/compare/v0.5.2...v0.5.3>`_

* Updated 3rd party requirements. Some requirements had changed so it was causing failures

0.5.4 (2018-10-29)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-user-activities/compare/v0.5.3...v0.5.4>`_

* Updated 3rd party requirements.
